@@ -131,13 +131,13 @@ class VariableOsInstallLocaleLang(LocaleVariable):
     Full language (at example: ru_RU)
     """
     mode = 'w'
-    metavalue = "LANG"
+    metavalue = "LOCALE"
     type = 'choice'
-    opt = ["--lang", "-l"]
+    opt = ["--locale", "-l"]
 
     def init(self):
-        self.label = _("Language")
-        self.help = _("set the language")
+        self.label = _("Locale")
+        self.help = _("set the locale")
 
     def get(self):
         """lang (example: ru_RU)"""
@@ -261,7 +261,7 @@ class VariableOsInstallClockTimezone(LocaleVariable):
                   "Asia/Beirut",
                   "Europe/Helsinki",
                   "Europe/Kiev",
-                  "Europa/Sofia",
+                  "Europe/Sofia",
                   "Africa/Windhoek",
                   "Asia/Jerusalem",
                   "Africa/Cairo",
@@ -309,6 +309,8 @@ class VariableOsInstallClockTimezone(LocaleVariable):
                   "Pacific/Auckland",
                   "Etc/GMT-13"]
 
+        source = list(set(source + Locale().getFields('timezone')))
+
         def sortkey(s):
             tz = timezone(s)
             strinfo = tz.localize(datetime.now()).strftime('%z')
@@ -321,7 +323,7 @@ class VariableOsInstallClockTimezone(LocaleVariable):
             source = nativeTZ + ["---"] + \
                      sorted(filter(lambda x: not x in nativeTZ, source),
                             key=sortkey)
-        except (KeyError, IndexError):
+        except (KeyError, IndexError) as e:
             pass
         return list(self.generateComments(source))
 
